==> haskell-monad-par-extras-0.3.3-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par-extras
version: 0.3.3
id: monad-par-extras-0.3.3-L8Gz4t5FuW362xtJ9I9RBD
key: monad-par-extras-0.3.3-L8Gz4t5FuW362xtJ9I9RBD
license: BSD-3-Clause
copyright: (c) Ryan Newton 2012
maintainer: Ryan Newton <rrnewton@gmail.com>
author: Ryan Newton, Simon Marlow
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.
category: Control,Parallelism,Monads
abi: 10d730c331c8d3cff4b88f52e9f5041d
exposed: True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State
hidden-modules: Control.Monad.Par.Pedigree
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-extras-0.3.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-par-extras-0.3.3
hs-libraries: HSmonad-par-extras-0.3.3-L8Gz4t5FuW362xtJ9I9RBD
depends:
    base-4.11.1.0 abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC deepseq-1.4.3.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV mtl-2.2.2 transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv=5a85b2fc79fc8de0f76069f2f5dd4dba
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=91a5befe140ca1e57734aef5b9be7102
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock
haddock-html: /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-extras-0.3.3-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par-extras
version: 0.3.3
id: monad-par-extras-0.3.3-BucfNBWHfBuE0IE6odEDx0
key: monad-par-extras-0.3.3-BucfNBWHfBuE0IE6odEDx0
license: BSD-3-Clause
copyright: (c) Ryan Newton 2012
maintainer: Ryan Newton <rrnewton@gmail.com>
author: Ryan Newton, Simon Marlow
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.
category: Control,Parallelism,Monads
abi: e6c895de0eda073e5cd0a5d1810dee6f
exposed: True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State
hidden-modules: Control.Monad.Par.Pedigree
import-dirs: /usr/lib/ghc-8.6.1/site-local/monad-par-extras-0.3.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/monad-par-extras-0.3.3
hs-libraries: HSmonad-par-extras-0.3.3-BucfNBWHfBuE0IE6odEDx0
depends:
    abstract-par-0.3.3-7eQ2qvh3JUrFV0IzAkpSDj base-4.12.0.0
    cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8 deepseq-1.4.4.0 mtl-2.2.2
    random-1.1-3ypV4EIycgb35PKjTYYr5q transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock
haddock-html: /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
